@@ -1,7 +1,7 @@
 /**************************************************************************
 * This file is part of the WebIssues Desktop Client program
 * Copyright (C) 2006 Michał Męciński
-* Copyright (C) 2007-2011 WebIssues Team
+* Copyright (C) 2007-2012 WebIssues Team
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
@@ -80,6 +80,8 @@ Application::Application( int& argc, char** argv ) : QApplication( argc, argv ),
 
 #if defined( Q_WS_WIN )
     setStyle( "XmlUi::WindowsStyle" );
+#elif defined( Q_WS_MAC )
+    setStyle( "XmlUi::MacStyle" );
 #endif
 
     setWindowIcon( IconLoader::icon( "webissues" ) );
@@ -151,7 +153,7 @@ void Application::about()
         " it under the terms of the GNU General Public License as published by"
         " the Free Software Foundation, either version 3 of the License, or"
         " (at your option) any later version." ) + "</p>";
-    message += "<p>" + trUtf8( "Copyright (C) 2006 Michał Męciński" ) + "<br>" + tr( "Copyright (C) 2007-2011 WebIssues Team" ) + "</p>";
+    message += "<p>" + trUtf8( "Copyright &copy; 2006 Michał Męciński" ) + "<br>" + tr( "Copyright &copy; 2007-2012 WebIssues Team" ) + "</p>";
 
     QString link = "<a href=\"http://webissues.mimec.org\">webissues.mimec.org</a>";
 
@@ -291,7 +293,7 @@ void Application::openDownloads()
 
 QString Application::version() const
 {
-    return QString( "1.0" );
+    return QString( "1.0.2" );
 }
 
 QString Application::protocolVersion() const
