@@ -1,18 +1,30 @@
 /**************************************************************************
-* This file is part of the WebIssues program
+* This file is part of the WebIssues Desktop Client program
 * Copyright (C) 2006 Michał Męciński
-* Copyright (C) 2007-2009 WebIssues Team
+* Copyright (C) 2007-2012 WebIssues Team
 *
-* This program is free software; you can redistribute it and/or modify
+* This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
-* the Free Software Foundation; either version 2 of the License, or
+* the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
+*
+* This program is distributed in the hope that it will be useful,
+* but WITHOUT ANY WARRANTY; without even the implied warranty of
+* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+* GNU General Public License for more details.
+*
+* You should have received a copy of the GNU General Public License
+* along with this program.  If not, see <http://www.gnu.org/licenses/>.
 **************************************************************************/
 
 #include "command.h"
+#include "formdatamessage.h"
+
+#include <QNetworkAccessManager>
 
 Command::Command() :
-    m_acceptBinaryResponse( false ),
+    m_attachmentInput( NULL ),
+    m_binaryResponseOutput( NULL ),
     m_acceptNullReply( false ),
     m_reportNullReply( false )
 {
@@ -36,23 +48,3 @@ void Command::addRule( const QString& signature, ReplyRule::Multiplicity multipl
 {
     m_rules.append( ReplyRule( signature, multiplicity ) );
 }
-
-void Command::setSendProgress( int done, int total )
-{
-    emit sendProgress( done, total );
-}
-
-void Command::setReadProgress( int done, int total )
-{
-    emit readProgress( done, total );
-}
-
-void Command::setCommandReply( const Reply& reply )
-{
-    emit commandReply( reply );
-}
-
-void Command::setBinaryBlock( const char* data, int length )
-{
-    emit binaryBlock( data, length );
-}
