@@ -1,7 +1,7 @@
 /**************************************************************************
 * This file is part of the WebIssues Desktop Client program
 * Copyright (C) 2006 Michał Męciński
-* Copyright (C) 2007-2011 WebIssues Team
+* Copyright (C) 2007-2012 WebIssues Team
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
@@ -22,6 +22,7 @@
 #include "application.h"
 #include "data/datamanager.h"
 #include "data/localsettings.h"
+#include "dialogs/messagebox.h"
 #include "models/reportgenerator.h"
 #include "utils/textwriter.h"
 #include "utils/csvwriter.h"
@@ -35,7 +36,6 @@
 #include <QTextDocument>
 #include <QPrintDialog>
 #include <QFileDialog>
-#include <QMessageBox>
 #include <QTextStream>
 #include <QTextCodec>
 #include <QSettings>
@@ -210,7 +210,7 @@ bool ReportDialog::exportCsv()
 
     QFile file( fileName );
     if ( !file.open( QIODevice::WriteOnly ) ) {
-        QMessageBox::warning( this, tr( "Warning" ), tr( "File could not be saved." ) );
+        MessageBox::warning( this, tr( "Warning" ), tr( "File could not be saved." ) );
         return false;
     }
 
@@ -231,7 +231,7 @@ bool ReportDialog::exportHtml()
 
     QFile file( fileName );
     if ( !file.open( QIODevice::WriteOnly ) ) {
-        QMessageBox::warning( this, tr( "Warning" ), tr( "File could not be saved." ) );
+        MessageBox::warning( this, tr( "Warning" ), tr( "File could not be saved." ) );
         return false;
     }
 
