@@ -1,7 +1,7 @@
 /**************************************************************************
 * This file is part of the WebIssues Desktop Client program
 * Copyright (C) 2006 Michał Męciński
-* Copyright (C) 2007-2011 WebIssues Team
+* Copyright (C) 2007-2012 WebIssues Team
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
@@ -26,6 +26,9 @@
 
 #include <QTreeView>
 #include <QHeaderView>
+#include <QTextDocument>
+#include <QHelpEvent>
+#include <QToolTip>
 
 class ExpandedNode
 {
@@ -89,6 +92,9 @@ void TreeViewHelper::initializeView( ViewFlags flags /*= 0*/ )
 
     m_view->setContextMenuPolicy( Qt::CustomContextMenu );
     m_view->header()->setContextMenuPolicy( Qt::CustomContextMenu );
+
+    if ( ( flags & NoAutoToolTip ) == 0 )
+        m_view->setItemDelegate( new AutoToolTipDelegate( m_view ) );
 }
 
 QModelIndex TreeViewHelper::selectedIndex()
@@ -133,8 +139,10 @@ void TreeViewHelper::saveColumnWidths( const QString& key, const QList<int>& col
 
     QMap<int, int> widths = dataManager->connectionSettings()->value( key ).value<LocalSettings::IntMap>();
 
-    for ( int i = 0; i < count; i++ )
-        widths.insert( columns.at( i ), m_view->columnWidth( i ) );
+    for ( int i = 0; i < count; i++ ) {
+        if ( !m_view->isColumnHidden( i ) )
+            widths.insert( columns.at( i ), m_view->columnWidth( i ) );
+    }
 
     dataManager->connectionSettings()->setValue( key, QVariant::fromValue( widths ) );
 }
@@ -191,3 +199,34 @@ void TreeViewHelper::loadExpandedNodes( const QString& key )
             m_view->setExpanded( index, true );
     }
 }
+
+AutoToolTipDelegate::AutoToolTipDelegate( QObject* parent ) : QStyledItemDelegate( parent )
+{
+}
+
+AutoToolTipDelegate::~AutoToolTipDelegate()
+{
+}
+
+bool AutoToolTipDelegate::helpEvent( QHelpEvent* e, QAbstractItemView* view, const QStyleOptionViewItem& option, const QModelIndex& index )
+{
+    if ( !e || !view )
+        return false;
+
+    if ( e->type() == QEvent::ToolTip ) {
+        QRect rect = view->visualRect( index );
+        QSize size = sizeHint( option, index );
+        if ( rect.width() < size.width() ) {
+            QVariant tooltip = index.data( Qt::DisplayRole );
+            if ( tooltip.canConvert<QString>() ) {
+                QToolTip::showText( e->globalPos(), QString( "<div>%1</div>" ).arg( Qt::escape( tooltip.toString() ) ), view );
+                return true;
+            }
+        }
+        if ( !QStyledItemDelegate::helpEvent( e, view, option, index ) )
+            QToolTip::hideText();
+        return true;
+    }
+
+    return QStyledItemDelegate::helpEvent( e, view, option, index );
+}
