@@ -1,7 +1,7 @@
 /**************************************************************************
 * This file is part of the WebIssues Desktop Client program
 * Copyright (C) 2006 Michał Męciński
-* Copyright (C) 2007-2011 WebIssues Team
+* Copyright (C) 2007-2012 WebIssues Team
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
@@ -217,7 +217,7 @@ FolderView::FolderView( QObject* parent, QWidget* parentWidget ) : View( parent
     mainLayout->addWidget( m_list );
 
     TreeViewHelper helper( m_list );
-    helper.initializeView();
+    helper.initializeView( TreeViewHelper::NoAutoToolTip );
 
     connect( m_list, SIGNAL( customContextMenuRequested( const QPoint& ) ),
         this, SLOT( listContextMenu( const QPoint& ) ) );
@@ -540,7 +540,7 @@ void FolderView::printReport()
 
     ReportDialog dialog( ReportDialog::FolderSource, ReportDialog::Print, mainWidget() );
     dialog.setFolder( id(), visibleIssues() );
-    dialog.setColumns( m_model->columns(), cache->availableColumns() );
+    dialog.setColumns( visibleColumns(), cache->availableColumns() );
     dialog.exec();
 }
 
@@ -550,7 +550,7 @@ void FolderView::exportCsv()
 
     ReportDialog dialog( ReportDialog::FolderSource, ReportDialog::ExportCsv, mainWidget() );
     dialog.setFolder( id(), visibleIssues() );
-    dialog.setColumns( m_model->columns(), cache->availableColumns() );
+    dialog.setColumns( visibleColumns(), cache->availableColumns() );
     dialog.exec();
 }
 
@@ -560,7 +560,7 @@ void FolderView::exportHtml()
 
     ReportDialog dialog( ReportDialog::FolderSource, ReportDialog::ExportHtml, mainWidget() );
     dialog.setFolder( id(), visibleIssues() );
-    dialog.setColumns( m_model->columns(), cache->availableColumns() );
+    dialog.setColumns( visibleColumns(), cache->availableColumns() );
     dialog.exec();
 }
 
@@ -570,7 +570,7 @@ void FolderView::exportPdf()
 
     ReportDialog dialog( ReportDialog::FolderSource, ReportDialog::ExportPdf, mainWidget() );
     dialog.setFolder( id(), visibleIssues() );
-    dialog.setColumns( m_model->columns(), cache->availableColumns() );
+    dialog.setColumns( visibleColumns(), cache->availableColumns() );
     dialog.exec();
 }
 
@@ -630,6 +630,9 @@ void FolderView::updateEvent( UpdateEvent* e )
 
         if ( e->unit() == UpdateEvent::States )
             updateActions();
+
+        if ( e->unit() == UpdateEvent::Settings )
+            loadCurrentView( false );
     }
 
     if ( isEnabled() && m_gotoIssueId != 0 && e->unit() == UpdateEvent::Folder && e->id() == id() ) {
@@ -858,6 +861,8 @@ void FolderView::loadCurrentView( bool resort )
 
     helper.loadColumnWidths( "FolderViewWidths", m_model->columns(), cache->defaultWidths() );
 
+    m_list->setColumnHidden( 0, dataManager->setting( "hide_id_column" ).toInt() != 0 );
+
     if ( resort )
         emit currentViewChanged( m_currentViewId );
 }
@@ -874,3 +879,17 @@ QList<int> FolderView::visibleIssues()
 
     return list;
 }
+
+QList<int> FolderView::visibleColumns()
+{
+    QList<int> list;
+
+    QList<int> columns = m_model->columns();
+
+    for ( int i = 0; i < columns.count(); i++ ) {
+        if ( !m_list->isColumnHidden( i ) )
+            list.append( columns.at( i ) );
+    }
+
+    return list;
+}
