@@ -1,7 +1,7 @@
 /**************************************************************************
 * This file is part of the WebIssues Desktop Client program
 * Copyright (C) 2006 Michał Męciński
-* Copyright (C) 2007-2011 WebIssues Team
+* Copyright (C) 2007-2012 WebIssues Team
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
@@ -179,7 +179,7 @@ void InputLineEdit::calculateLayout()
         m_errorLabel->hide();
     }
 
-#if QT_VERSION >= 0x040500
+#if ( QT_VERSION >= 0x040500 )
     setTextMargins( 0, 0, padding, 0 );
 #else
     setStyleSheet( QString( "QLineEdit { padding-right: %1px; }" ).arg( padding ) );
@@ -323,6 +323,10 @@ void EnumLineEdit::setItems( const QStringList& items )
     completer->setCaseSensitivity( Qt::CaseInsensitive );
     completer->setMultiSelect( m_multiSelect );
 
+#if ( QT_VERSION >= 0x040600 )
+    completer->setMaxVisibleItems( 10 );
+#endif
+
     setCompleter( completer );
 
     setPopupVisible( !items.isEmpty() );
